@@ -4,7 +4,6 @@ import luigi
 import yaml
 
 from servicecatalog_puppet import manifest_utils
-
 from servicecatalog_puppet.workflow import tasks
 
 
@@ -21,13 +20,6 @@ class ManifestMixen(object):
 class SectionTask(tasks.PuppetTask, ManifestMixen):
     manifest_file_path = luigi.Parameter()
     puppet_account_id = luigi.Parameter()
-    should_use_sns = luigi.BoolParameter()
-    should_use_product_plans = luigi.BoolParameter()
-    include_expanded_from = luigi.BoolParameter()
-    single_account = luigi.Parameter()
-    is_dry_run = luigi.BoolParameter()
-    execution_mode = luigi.Parameter()
-    cache_invalidator = luigi.Parameter()
 
     def params_for_results_display(self):
         return {
